% open ScrollWave image and convert from uint8 to double
pic_data_gray = double(rgb2gray(imread('ScrollWave.png')));

% perform SVD on ScrollWave
[U,S,V] = svd(pic_data_gray);

% extract singular values
singvals = diag(S);

% find out where to truncate the U, S, V matrices
indices = find(singvals >= 0.01 * singvals(1));

% reduce SVD matrices
U_red = U(:,indices);
S_red = S(indices,indices);
V_red = V(:,indices);

% construct low-rank approximation of ScrollWave
ScrollWave_red = U_red * S_red * V_red';

% print results to command window
r = num2str(length(indices));
m = num2str(length(singvals));
disp(['Low-rank approximation used ',r,' of ',m,' singular values']);

% save reduced ScrollWave
imshow(uint8(ScrollWave_red))
imwrite(uint8(ScrollWave_red),'ReducedScrollWaveGray.png');

% save gray data of reduced pic (ScrollWave_red=W_red*Z_red)
W_red = U_red * sqrt(S_red);
Z_red = sqrt(S_red) * V_red';
%W_red=round(W_red,1); Z_red=round(Z_red,1);
save('data_red_gray.mat','W_red','Z_red');
%imshow(uint8(W_red*Z_red));

% save gray data of original pic 
save('data_orig_gray.mat','pic_data_gray');